<?php
/**
 * Widget template
 *
 * @package Travel_Gem
 */

$qargs = array(
	'post_type'           => 'product',
	'post_status'         => 'publish',
	'ignore_sticky_posts' => 1,
	'posts_per_page'      => absint( $instance['post_number'] ),
	'no_found_rows'       => true,
);
if ( absint( $instance['post_category'] ) > 0 ) {
	$qargs['tax_query'] = array(
		array(
			'taxonomy' => 'product_cat',
			'field'    => 'term_id',
			'terms'    => absint( $instance['post_category'] ),
			),
		);
}

global $woocommerce_loop;
$products = new WP_Query( $qargs );
?>

<div class="section section-products-carousel heading-<?php echo esc_attr( $instance['heading_alignment'] ); ?>">

	<?php if ( ! empty( $instance['title'] ) ) : ?>
		<?php echo $args['before_title'] . esc_html( $instance['title'] ) . $args['after_title']; ?>
	<?php endif; ?>

	<?php if ( ! empty( $instance['subtitle'] ) ) : ?>
		<p class="widget-subtitle"><?php echo esc_html( $instance['subtitle'] ); ?></p>
	<?php endif; ?>

	<?php if ( class_exists( 'WooCommerce' ) ) : ?>
		<?php
		if ( $products->have_posts() ) {

			$carousel_args = array(
				'slidesToShow'   => 4,
				'slidesToScroll' => 1,
				'dots'           => false,
				'prevArrow'      => '<span data-role="none" class="slick-prev" tabindex="0"><i class="fas fa-angle-left" aria-hidden="true"></i></span>',
				'nextArrow'      => '<span data-role="none" class="slick-next" tabindex="0"><i class="fas fa-angle-right" aria-hidden="true"></i></span>',
				'responsive'   => array(
					array(
						'breakpoint' => 1024,
						'settings'   => array(
							'slidesToShow' => 4,
							),
						),
					array(
						'breakpoint' => 800,
						'settings'   => array(
							'slidesToShow' => 3,
							),
						),
					array(
						'breakpoint' => 659,
						'settings'   => array(
							'slidesToShow' => 2,
							),
						),
					array(
						'breakpoint' => 479,
						'settings'   => array(
							'slidesToShow' => 1,
							),
						),
					),
				);

			if ( true === $instance['settings']['enable_autoplay'] ) {
				$carousel_args['autoplay']      = true;
				$carousel_args['autoplaySpeed'] = 1000 * absint( $instance['settings']['transition_delay'] );
			}

			$carousel_args_encoded = wp_json_encode( $carousel_args );
			?>

			<div class="travel-gem-woocommerce">

				<ul class="products products-carousel-wrapper" data-slick='<?php echo $carousel_args_encoded; ?>'>

					<?php while ( $products->have_posts() ) : $products->the_post(); ?>

						<?php wc_get_template_part( 'content', 'product' ); ?>

					<?php endwhile; ?>

				</ul><!-- .products -->

			</div><!-- .travel-gem-woocommerce -->

			<?php
		}
		woocommerce_reset_loop();
		wp_reset_postdata();
		?>
	<?php else : ?>

		<?php if ( current_user_can( 'activate_plugins' ) ) : ?>

			<p><?php esc_html_e( 'WooCommerce plugin is not active. Please install and activate the plugin first.', 'travel-gem-pro' ); ?></p>

		<?php endif; ?>

	<?php endif; ?>

</div><!-- .section-products-carousel -->
