<?php
/**
 * Services widget
 *
 * Widget Name: Travel Gem Services
 * Description: Displays services blocks.
 * Author: WEN Themes
 * Author URI: https://wenthemes.com
 *
 * @package Travel_Gem
 */

/**
 * Services widget class.
 *
 * @since 1.0.0
 */
class Travel_Gem_Services_Widget extends SiteOrigin_Widget {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		parent::__construct(
			'travel-gem-services',
			esc_html__( 'Travel Gem: Services', 'travel-gem-pro' ),
			array(
				'description' => esc_html__( 'Displays services blocks.', 'travel-gem-pro' ),
			),
			array(),
			false,
			plugin_dir_path( __FILE__ )
		);
	}

	/**
	 * Get widget form.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget form.
	 */
	function get_widget_form() {

		return array(
			'title' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Title', 'travel-gem-pro' ),
				),
			'subtitle' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Subtitle', 'travel-gem-pro' ),
				),
			'heading_alignment' => array(
				'label'   => esc_html__( 'Title/subtitle Alignment', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'center',
				'options' => travel_gem_get_heading_alignment_options(),
				),
			'services' => array(
				'type'       => 'repeater',
				'label'      => esc_html__( 'Services', 'travel-gem-pro' ),
				'item_name'  => esc_html__( 'Service', 'travel-gem-pro' ),
				'item_label' => array(
					'selector'     => "[id*='services-service_title']",
					'update_event' => 'change',
					'value_method' => 'val',
					),
				'fields' => array(
					'service_title' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Title', 'travel-gem-pro' ),
						),
					'service_url' => array(
						'type'  => 'link',
						'label' => esc_html__( 'Link', 'travel-gem-pro' ),
						),
					'service_icon' => array(
						'type'  => 'icon',
						'label' => esc_html__( 'Icon', 'travel-gem-pro' ),
						),
					'service_icon_color' => array(
						'type'  => 'color',
						'label' => esc_html__( 'Icon Color', 'travel-gem-pro' ),
						),
					'service_description' => array(
						'type'  => 'textarea',
						'label' => esc_html__( 'Description', 'travel-gem-pro' ),
						),
					),
				),
			'settings' => array(
				'label'  => esc_html__( 'Settings', 'travel-gem-pro' ),
				'type'   => 'section',
				'hide'   => false,
				'fields' => array(
					'layout' => array(
						'label'   => esc_html__( 'Select Layout', 'travel-gem-pro' ),
						'type'    => 'select',
						'default' => 1,
						'options' => travel_gem_get_numbers_dropdown_options( 1, 2 ),
						),
					'post_column' => array(
						'label'   => esc_html__( 'Number of Columns', 'travel-gem-pro' ),
						'type'    => 'select',
						'default' => 3,
						'options' => travel_gem_get_numbers_dropdown_options( 2, 4 ),
						),
					'new_window' => array(
						'label'   => esc_html__( 'Open URL in new window', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => false,
						),
					),
				),
			);
	}

}

siteorigin_widget_register( 'travel-gem-services', __FILE__, 'Travel_Gem_Services_Widget' );
