<?php
/**
 * Slider widget
 *
 * Widget Name: Travel Gem Slider
 * Description: Displays slider.
 * Author: WEN Themes
 * Author URI: https://wenthemes.com
 *
 * @package Travel_Gem
 */

/**
 * Slider widget class.
 *
 * @since 1.0.0
 */
class Travel_Gem_Slider_Widget extends SiteOrigin_Widget {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		parent::__construct(
			'travel-gem-slider',
			esc_html__( 'Travel Gem: Slider', 'travel-gem-pro' ),
			array(
				'description' => esc_html__( 'Displays slider.', 'travel-gem-pro' ),
			),
			array(),
			false,
			plugin_dir_path( __FILE__ )
		);
	}

	/**
	 * Initialize.
	 *
	 * @since 1.0.0
	 */
	function initialize() {

		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		// Script handle is kept same as plugin to avoid multiple loading.
		wp_enqueue_script(
			'sow-slider-slider-cycle2',
			plugin_dir_url( SOW_BUNDLE_BASE_FILE ) . '/js/jquery.cycle' . $min . '.js',
			array( 'jquery' ),
			'2.1.6'
		);

		add_action( 'siteorigin_widgets_before_widget_travel-gem-slider', array( $this, 'enqueue_widget_scripts' ) );
	}

	/**
	 * Enqueue widget scripts.
	 *
	 * @since 1.0.0
	 *
	 * @param array $instance Instance.
	 */
	function enqueue_widget_scripts( $instance ) {

		$effect = isset( $instance['settings']['transition_effect'] ) ? $instance['settings']['transition_effect'] : '';
		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		switch ( $effect ) {
			case 'tileSlide':
			case 'tileBlind':
				wp_enqueue_script(
					'travel-gem-cycle2-tile',
					get_template_directory_uri() . '/third-party/cycle2/js/jquery.cycle2.tile' . $min . '.js',
					array( 'jquery', 'sow-slider-slider-cycle2' ),
					'2.1.6'
				);
				break;

			case 'flipHorz':
			case 'flipVert':
				wp_enqueue_script(
					'travel-gem-cycle2-flip',
					get_template_directory_uri() . '/third-party/cycle2/js/jquery.cycle2.flip' . $min . '.js',
					array( 'jquery', 'sow-slider-slider-cycle2' ),
					'2.1.6'
				);
				break;

			case 'shuffle':
				wp_enqueue_script(
					'travel-gem-cycle2-shuffle',
					get_template_directory_uri() . '/third-party/cycle2/js/jquery.cycle2.shuffle' . $min . '.js',
					array( 'jquery', 'sow-slider-slider-cycle2' ),
					'2.1.6'
				);
				break;

			default:
				break;
		}
	}

	/**
	 * Get widget form.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget form.
	 */
	function get_widget_form() {

		return array(
			'slider' => array(
				'type'       => 'repeater',
				'label'      => esc_html__( 'Slider', 'travel-gem-pro' ),
				'item_name'  => esc_html__( 'Slide', 'travel-gem-pro' ),
				'item_label' => array(
					'selector'     => "[id*='slider-slide_title']",
					'update_event' => 'change',
					'value_method' => 'val',
					),
				'fields' => array(
					'slide_title' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Title', 'travel-gem-pro' ),
						),
					'slide_subtitle' => array(
						'type'  => 'textarea',
						'label' => esc_html__( 'Description', 'travel-gem-pro' ),
						),
					'slide_image' => array(
						'type'     => 'media',
						'label'    => esc_html__( 'Image', 'travel-gem-pro' ),
						'library'  => 'image',
						'choose'   => esc_html__( 'Choose Image', 'travel-gem-pro' ),
						'update'   => esc_html__( 'Set Image', 'travel-gem-pro' ),
						'fallback' => true,
						),
					'slide_url' => array(
						'type'  => 'link',
						'label' => esc_html__( 'Destination URL', 'travel-gem-pro' ),
						),
					'primary_button_text' => array(
						'type'    => 'text',
						'label'   => esc_html__( 'Primary Button Text', 'travel-gem-pro' ),
						'default' => esc_html__( 'Know More', 'travel-gem-pro' ),
						),
					'primary_button_url' => array(
						'type'  => 'link',
						'label' => esc_html__( 'Primary Button URL', 'travel-gem-pro' ),
						),
					'secondary_button_text' => array(
						'type'    => 'text',
						'label'   => esc_html__( 'Secondary Button Text', 'travel-gem-pro' ),
						'default' => esc_html__( 'Learn More', 'travel-gem-pro' ),
						),
					'secondary_button_url' => array(
						'type'  => 'link',
						'label' => esc_html__( 'Secondary Button URL', 'travel-gem-pro' ),
						),
					'caption_alignment' => array(
						'type'    => 'select',
						'label'   => esc_html__( 'Caption Alignment', 'travel-gem-pro' ),
						'default' => 'center',
						'options' => travel_gem_get_alignment_options( array( 'center', 'left', 'right' ) ),
						),
					'slide_title_color' => array(
						'label'   => esc_html__( 'Slide Title Color', 'travel-gem-pro' ),
						'type'    => 'color',
						'default' => '#FFF',
						),
					'slide_subtitle_color' => array(
						'label'   => esc_html__( 'Slide Subtitle Color', 'travel-gem-pro' ),
						'type'    => 'color',
						'default' => '#FFF',
						),
					),
				),
			'settings' => array(
				'label'  => esc_html__( 'Settings', 'travel-gem-pro' ),
				'type'   => 'section',
				'hide'   => false,
				'fields' => array(
					'transition_effect' => array(
						'label'   => esc_html__( 'Transition Effect', 'travel-gem-pro' ),
						'type'    => 'select',
						'default' => 'fade',
						'options' => travel_gem_get_slider_transition_effects_options(),
						),
					'transition_delay' => array(
						'label'       => esc_html__( 'Transition Delay', 'travel-gem-pro' ),
						'description' => esc_html__( 'in seconds', 'travel-gem-pro' ),
						'type'        => 'number',
						'default'     => 3,
						),
					'transition_duration' => array(
						'label'       => esc_html__( 'Transition Duration', 'travel-gem-pro' ),
						'description' => esc_html__( 'in seconds', 'travel-gem-pro' ),
						'type'        => 'number',
						'default'     => 1,
						),
					'enable_caption' => array(
						'label'   => esc_html__( 'Enable Caption', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => true,
						),
					'enable_autoplay' => array(
						'label'   => esc_html__( 'Enable Autoplay', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => true,
						),
					'enable_overlay' => array(
						'label'   => esc_html__( 'Enable Overlay', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => true,
						),
					'enable_arrow' => array(
						'label'   => esc_html__( 'Enable Arrow', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => true,
						),
					'enable_pager' => array(
						'label'   => esc_html__( 'Enable Pager', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => false,
						),
					),
				),
			);
	}

}

siteorigin_widget_register( 'travel-gem-slider', __FILE__, 'Travel_Gem_Slider_Widget' );
